"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPackageDirs = exports.resolveTargetOrg = void 0;
const core_1 = require("@salesforce/core");
const resolveTargetOrg = async (targetOrg) => {
    const configuredTargetOrg = getConfigValue(core_1.OrgConfigProperties.TARGET_ORG);
    const aliasOrUsername = targetOrg || configuredTargetOrg;
    if (!aliasOrUsername) {
        throw new core_1.SfdxError('no target environment specified', 'NoTargetEnv', [
            'specify target environment with the --target-org flag',
            'set the default environment with "sf config set target-org"',
        ]);
    }
    return (await core_1.GlobalInfo.getInstance()).aliases.resolveUsername(aliasOrUsername);
};
exports.resolveTargetOrg = resolveTargetOrg;
const getPackageDirs = async () => {
    const project = await core_1.SfdxProject.resolve();
    return project.getUniquePackageDirectories().map((pDir) => pDir.fullPath);
};
exports.getPackageDirs = getPackageDirs;
const getConfigValue = (key) => {
    var _a;
    return (_a = core_1.ConfigAggregator.getValue(key)) === null || _a === void 0 ? void 0 : _a.value;
};
//# sourceMappingURL=orgs.js.map